==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/lt_LT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ar norite pridėti nuotolinį viešinį {name} iš {owner}@{remote}?",
    "Remote share" : "Nuotolinis viešinys",
    "Remote share password" : "Nuotolinio viešinio slaptažodis",
    "Cancel" : "Atsisakyti",
    "Add remote share" : "Pridėti nuotolinį viešinį",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
    "Invalid Federated Cloud ID" : "Neteisingas federacinės debesijos ID",
    "Server to server sharing is not enabled on this server" : "Dalinimasis tarp serverių yra neleidžiamas šiame serveryje",
    "Couldn't establish a federated share." : "Nepavyko užmegzti federacinio viešinio.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepavyko užmegzti federacinio viešinio, galbūt, neteisingas slaptažodis.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federacinio viešinio užklausa išsiųsta, jūs gausite pakvietimą. Tikrinkite savo pranešimus.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepavyko užmegzti federacinio viešinio, atrodo, kad serveris su kuriuo ketinama jungtis į federaciją yra per senas (Nextcloud <= 9).",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Nepavyko bendrinti %1$s, nes šis elementas jau yra bendrinamas su %2$s",
    "Not allowed to create a federated share with the same user" : "Negalima sukurti federacinį viešinį su tuo pačiu naudotoju",
    "File is already shared with %s" : "Failas jau yra bendrinamas su %s",
    "Could not find share" : "Nepavyko rasti bendrinamų duomenų",
    "Federated sharing" : "Federacinis bendrinimas",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Gavote galimybę peržiūrėti duomenis \"{share}\", kuriuos pasidalino {user} ({behalf} vardu) esantis kitame serveryje",
    "You received {share} as a remote share from {user}" : "Gavote galimybę peržiūrėti duomenis \"{share}\", kuriuos pasidalino {user}",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Bendrinti su manimi per mano #Nextcloud federacinės debesijos ID",
    "Sharing" : "Duomenų bendrinimas",
    "Federated file sharing" : "Federacinis failų bendrinimas",
    "Federated Cloud Sharing" : "Bendrinimas federacinėje debesijoje",
    "Open documentation" : "Atverti dokumentaciją",
    "Adjust how people can share between servers." : "Derinkite kaip žmonės gali bendrinti tarp serverių.",
    "Allow users on this server to receive shares from other servers" : "Leisti naudotojams šiame serveryje gauti viešinius iš kitų serverių",
    "Allow users on this server to send shares to groups on other servers" : "Leisti naudotojams šiame serveryje siųsti viešinius į grupes kituose serveriuose",
    "Allow users on this server to receive group shares from other servers" : "Leisti naudotojams šiame serveryje gauti grupių viešinius iš kitų serverių",
    "Search global and public address book for users" : "Ieškoti naudotojų visuotinėje ir viešoje adresų knygoje",
    "Allow users to publish their data to a global and public address book" : "Leisti naudotojams paskelbti savo duomenis visuotinėje ir viešoje adresų knygoje",
    "Federated Cloud" : "Federacinė debesija",
    "Your Federated Cloud ID:" : "Jūsų federacinės debesijos ID:",
    "Share it so your friends can share files with you:" : "Pasidalinkite juo, kad jūsų draugai galėtų bendrinti failus kartu su jumis:",
    "HTML Code:" : "HTML kodas:",
    "Allow users on this server to send shares to other servers" : "Leisti naudotojams šiame serveryje siųsti viešinius į kitus serverius"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-24.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/lt_LT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ar norite pridėti nuotolinį viešinį {name} iš {owner}@{remote}?",
    "Remote share" : "Nuotolinis viešinys",
    "Remote share password" : "Nuotolinio viešinio slaptažodis",
    "Cancel" : "Atsisakyti",
    "Add remote share" : "Pridėti nuotolinį viešinį",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
    "Invalid Federated Cloud ID" : "Neteisingas federacinės debesijos ID",
    "Server to server sharing is not enabled on this server" : "Dalinimasis tarp serverių yra neleidžiamas šiame serveryje",
    "Couldn't establish a federated share." : "Nepavyko užmegzti federacinio viešinio.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepavyko užmegzti federacinio viešinio, galbūt, neteisingas slaptažodis.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federacinio viešinio užklausa išsiųsta, jūs gausite pakvietimą. Tikrinkite savo pranešimus.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepavyko užmegzti federacinio viešinio, atrodo, kad serveris su kuriuo ketinama jungtis į federaciją yra per senas (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Iš šio serverio neleidžiama siųsti federacinių grupės viešinių.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Nepavyko bendrinti %1$s, nes šis elementas jau yra bendrinamas su naudotoju %2$s",
    "Not allowed to create a federated share with the same user" : "Negalima sukurti federacinį viešinį su tuo pačiu naudotoju",
    "File is already shared with %s" : "Failas jau yra bendrinamas su %s",
    "Could not find share" : "Nepavyko rasti bendrinamų duomenų",
    "Federated sharing" : "Federacinis bendrinimas",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Jūs gavote {share} kaip nuotolinį viešinį iš {user} ({behalf} vardu)",
    "You received {share} as a remote share from {user}" : "Jūs gavote {share} kaip nuotolinį viešinį iš {user}",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Federated Cloud Sharing" : "Bendrinimas federacinėje debesijoje",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Bendrinti su manimi per mano #Nextcloud federacinės debesijos ID",
    "Sharing" : "Duomenų bendrinimas",
    "Federated file sharing" : "Federacinis failų bendrinimas",
    "Allow users on this server to receive shares from other servers" : "Leisti naudotojams šiame serveryje gauti viešinius iš kitų serverių",
    "Allow users on this server to send shares to groups on other servers" : "Leisti naudotojams šiame serveryje siųsti viešinius į grupes kituose serveriuose",
    "Allow users on this server to receive group shares from other servers" : "Leisti naudotojams šiame serveryje gauti grupių viešinius iš kitų serverių",
    "Search global and public address book for users" : "Ieškoti naudotojų visuotinėje ir viešoje adresų knygoje",
    "Allow users to publish their data to a global and public address book" : "Leisti naudotojams paskelbti savo duomenis visuotinėje ir viešoje adresų knygoje",
    "Federated Cloud" : "Federacinė debesija",
    "Open documentation" : "Atverti dokumentaciją",
    "Your Federated Cloud ID:" : "Jūsų federacinės debesijos ID:",
    "Share it so your friends can share files with you:" : "Pasidalinkite juo, kad jūsų draugai galėtų bendrinti failus kartu su jumis:",
    "HTML Code:" : "HTML kodas:",
    "Adjust how people can share between servers." : "Derinkite kaip žmonės gali bendrinti tarp serverių."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
